-- Copyright © 2012 Xianghar  <xian@zron.de>
-- All Rights Reserved.
-- This code is not to be modified or distributed without written permission by the author.
-- Current distribution permissions only include curse.com, wowui.worldofwar.net, wowinterface.com and their respective addon updaters


local _, MonkTimers = ...

local Timers = XiTimers.timers

local SpellIDs = MonkTimers.SpellIDs
local SpellNames = MonkTimers.SpellNames
local AvailableSpells = MonkTimers.AvailableSpells

local LSM = LibStub:GetLibrary("LibSharedMedia-3.0", true)

local SettingsFunctions

function MonkTimers.ProcessSetting(setting)
    if SettingsFunctions[setting] then
        SettingsFunctions[setting](MonkTimers.ActiveProfile[setting], XiTimers.timers)
    end
end


function MonkTimers.ProcessAllSettings()
    for k,v in pairs(MonkTimers.ActiveProfile) do
        MonkTimers.ProcessSetting(k)
    end
end


SettingsFunctions = {
  --[[  ShowTimerBars = 
        function(value, Timers) 
            for _,timer in pairs(Timers) do
                timer.visibleTimerBars = value
                for n,t in pairs(timer.timers) do
                    if t>0 and value then
                        timer:ShowTimerBar(n)
                    else
                        timer.timerBars[n].background:Hide()
                        timer.timerBars[n]:SetValue(0)
                    end					
                end
            end
            Timers[20].visibleTimerBars = true
            if Timers[20].timers[1]>0 then
                Timers[20]:ShowTimerBar(n)
            end
        end,

    FlashRed = 
        function(value, Timers)
        	for _,timer in pairs(Timers) do
                timer.flashRed = value
            end
        end,
        
        
    Lock =
        function(value, Timers)
            for k,v in pairs(Timers) do
                v.locked = value
            end
        end,
     
    TimeFont =
        function(value, Timers)
            local font = LSM:Fetch("font", value)
            if font then
                for _,timer in pairs(Timers) do
                    timer:SetFont(font)
                end
            end
        end,
        
    TimerBarTexture =
        function(value, Timers) 
            local texture = LSM:Fetch("statusbar", value)
            if texture then
                for _,timer in pairs(Timers) do
                    timer:SetBarTexture(texture)
                end
            end
        end,
        
]]


    TimersOnButtons = 
        function(value, Timers)
            for i=1,#Timers do
                Timers[i].timerOnButton = value
                if not value and i > 8 and MonkTimers.ActiveProfile.CDTimersOnButtons then Timers[i].timerOnButton = true end
                if Timers[i].timers[1] > 0 then Timers[i]:Start(1, Timers[i].timers[1], Timers[i].durations[1]) end
                --if Timers[i].nrOfTimers > 1 and Timers[i].timers[2] > 0 then Timers[i]:Start(2, Timers[i].timers[2], Timers[i].durations[1]) end                    
            end
        end,
        
        
    Timers = 
        function(value)
            if value then
                MonkTimers.ActivateTimers() 
            else
                MonkTimers.DeactivateTimers()
            end
        end,
        
--[[     TimerSize =
        function(value, Timers)
            for i=9,21 do
                if i~= 20 then
                    Timers[i]:SetScale(value/36)
                end
            end
            MonkTimers.LayoutEnhanceCDs()
        end,
        
    EnhanceCDsTimeHeight = 
         function(value, Timers)
    		for e=9,21 do
                if e~= 20 then
                    Timers[e]:SetTimeHeight(value)
                    local font, _ = Timers[e].button.time:GetFont()
                    Timers[e].button.time:SetFont(font, value+5, "OUTLINE")
                end
    		end 
            MonkTimers.LayoutEnhanceCDs()
        end,
        
    EnhanceCDsMaelstromHeight = 
        function(value, Timers)
            MonkTimers.maelstrom:SetHeight(value)
            MonkTimers.maelstrom.background:SetHeight(value)
            MonkTimers.maelstrombutton:SetHeight(value)
            MonkTimers.maelstrom.icon:SetWidth(value)
            MonkTimers.maelstrom.icon:SetHeight(value)
            Timers[20]:SetScale(value/36)
            Timers[20]:SetTimeHeight(value)
            Timers[20].timerBars[1]:SetScale(36/value)
            local font = MonkTimers.maelstrom.text:GetFont()
            local outline
            if Timers[9].timerOnButton then outline = "OUTLINE" end
    		MonkTimers.maelstrom.text:SetFont(font, value, outline)
            local font, value = _G["XiTimers_TimerBar17_1Time"]:GetFont()
            _G["XiTimers_TimerBar17_1Time"]:SetFont(font, value, outline)
            MonkTimers.LayoutEnhanceCDs()
        end,
        
    Tooltips =  
        function(value, Timers)
            for i=1,8 do
                Timers[i].button:SetAttribute("tooltip", value)
            end
            for i=1,TTActionBars.numbars do
                TTActionBars.bars[i]:SetTooltip(value)
            end
        end,
        
       
    ShowKeybinds =
        function(value, Timers)
            for _,t in pairs(Timers) do
                if value then
                    t.button.hotkey:Show()
                else
                    t.button.hotkey:Hide()
                end
            end
        end,
        
    FramePositions = 
        function(value, Timers)
            for name, pos in pairs(value) do
                if _G[name] and pos and pos[1] then
                    _G[name]:ClearAllPoints()
                    _G[name]:SetPoint(pos[1],pos[2],pos[3],pos[4],pos[5])
                end
            end
        end,
        
      
        
    EnhanceCDsOOCAlpha = 
        function(value, Timers)
            for i = 9,21 do
                Timers[i].OOCAlpha = value
            end
            MonkTimers.maelstrom:SetAlpha(value)
            XiTimers.invokeOOCFader()
        end,
        
   
    TimeColor = 
        function(value, Timers)
            for i=1,#Timers do
                Timers[i].button.time:SetTextColor(value.r, value.g, value.b, 1)
                Timers[1].timeColor = value
                for j=1,#Timers[i].timerBars do
                    Timers[i].timerBars[j].time:SetTextColor(value.r,value.g,value.b,1)
                end
            end
        end,
        
   
    HideInVehicle = 
        function(value, Timers)
            if value then
                for k,v in pairs(Timers) do
                    RegisterStateDriver(v.button,"invehicle","[bonusbar:5]hide;show")
                end
                --RegisterStateDriver(MonkTimers.MB,"invehicle","[bonusbar:5]hide;show")
            else
                for k,v in pairs(Timers) do
                    UnregisterStateDriver(v.button,"invehicle")
                end
                --UnregisterStateDriver(MonkTimers.MB,"invehicle")
            end
        end,
   
    StopPulse =
        function(value, Timers)
            for i = 1,4 do
                Timers[i].StopPulse = value
            end
            for i = 6,8 do
                Timers[i].StopPulse = value
            end
        end,
        
    HideEnhanceCDsOOC =
        function(value, Timers)
            for i = 9,21 do
                Timers[i].HideOOC = value
            end
            MonkTimers.ConfigEnhanceCDs()
        end,
        
        
    EnhanceCDs_Clickthrough =
        function(value, Timers)
            for i = 9,21 do
                Timers[i].button:EnableMouse(not value)
            end
            MonkTimers.maelstrom:EnableMouse(not value)
            MonkTimers.maelstrombutton:EnableMouse(not value)
        end,
           
  ]]      
}



